@@ -317,6 +317,25 @@ def _geo_dask_to_data_array(arr: da.Array) -> xr.DataArray:
     return xr.DataArray(arr, dims=('y', 'x'))
 
 
+def compute_relative_azimuth(sat_azi: xr.DataArray, sun_azi: xr.DataArray) -> xr.DataArray:
+    """Compute the relative azimuth angle.
+
+    Args:
+        sat_azi: DataArray for the satellite azimuth angles, typically in 0-360 degree range.
+        sun_azi: DataArray for the solar azimuth angles, should be in same range as sat_azi.
+    Returns:
+        A DataArray containing the relative azimuth angle in the 0-180 degree range.
+
+    NOTE: Relative azimuth is defined such that:
+    Relative azimuth is 0 when sun and satellite are aligned on one side of a pixel (back scatter).
+    Relative azimuth is 180 when sun and satellite are directly opposite each other (forward scatter).
+    """
+    ssadiff = np.absolute(sun_azi - sat_azi)
+    ssadiff = np.minimum(ssadiff, 360 - ssadiff)
+
+    return ssadiff
+
+
 def get_angles(data_arr: xr.DataArray) -> tuple[xr.DataArray, xr.DataArray, xr.DataArray, xr.DataArray]:
     """Get sun and satellite azimuth and zenith angles.
 
@@ -412,6 +431,12 @@ def _get_sun_azimuth_ndarray(lons: np.ndarray, lats: np.ndarray, start_time: dat
     with ignore_invalid_float_warnings():
         suna = get_alt_az(start_time, lons, lats)[1]
         suna = np.rad2deg(suna)
+
+        # The get_alt_az function returns values in the range -180 to 180 degrees.
+        # Satpy expects values in the 0 - 360 range, which is what is returned for the
+        # satellite azimuth angles.
+        # Here this is corrected so both sun and sat azimuths are in the same range.
+        suna = suna % 360.
     return suna
 
 
@@ -499,7 +524,8 @@ def _sunzen_corr_cos_ndarray(data: np.ndarray,
         # gradually fall off for larger zenith angle
         grad_factor = (np.arccos(cos_zen) - limit_rad) / (max_sza_rad - limit_rad)
         # invert the factor so maximum correction is done at `limit` and falls off later
-        grad_factor = 1. - np.log(grad_factor + 1) / np.log(2)
+        with np.errstate(invalid='ignore'):  # we expect space pixels to be invalid
+            grad_factor = 1. - np.log(grad_factor + 1) / np.log(2)
         # make sure we don't make anything negative
         grad_factor = grad_factor.clip(0.)
     else:
