@@ -25,7 +25,6 @@ import numpy as np
 import pytest
 import xarray as xr
 
-from satpy.readers.agri_l1 import RESOLUTION_LIST
 from satpy.tests.reader_tests.test_hdf5_utils import FakeHDF5FileHandler
 
 ALL_BAND_NAMES = ["C01", "C02", "C03", "C04", "C05", "C06", "C07",
@@ -38,12 +37,20 @@ CHANNELS_BY_RESOLUTION = {500: ["C02"],
                           'GEO': 'solar_azimuth_angle'
                           }
 
-AREA_EXTENTS_BY_RESOLUTION = {
-    500:  (-5495771.007913081, 5495271.006001793, -5493771.000267932, 5495771.007913081),
-    1000: (-5495521.074086424, 5494521.070251633, -5491521.058747265, 5495521.074086424),
-    2000: (-5495021.206414789, 5493021.198696349, -5487021.175541028, 5495021.206414789),
-    4000: (-5494021.20255557, 5490021.187118688, -5478021.140808046, 5494021.20255557)
-}
+RESOLUTION_LIST = [500, 1000, 2000, 4000]
+
+AREA_EXTENTS_BY_RESOLUTION = {'FY4A': {
+    500: (-5495271.006002, -5496021.008869, -5493270.998357, -5495521.006957),
+    1000: (-5494521.070252, -5496021.076004, -5490521.054912, -5495021.072169),
+    2000: (-5493021.198696, -5496021.210274, -5485021.167823, -5494021.202556),
+    4000: (-5490021.187119, -5496021.210274, -5474021.125371, -5492021.194837)
+},
+    'FY4B': {
+    500: (-5495271.006002, -5496021.008869, -5493270.998357, -5495521.006957),
+    1000: (-5494521.070252, -5496021.076004, -5490521.054912, -5495021.072169),
+    2000: (-5493021.198696, -5496021.210274, -5485021.167823, -5494021.202556),
+    4000: (-5490021.187119, -5496021.210274, -5474021.125371, -5492021.194837)
+}}
 
 
 class FakeHDF5FileHandler2(FakeHDF5FileHandler):
@@ -91,7 +98,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
                                     'FillValue': np.array(65535.),
                                     'units': 'NUL',
                                     'band_names': 'NUL',
-                                    'valid_range': np.array([-180., 180.]),
+                                    'valid_range': np.array([0., 360.]),
                                 },
                                 dims=('_RegLength', '_RegWidth'))
 
@@ -125,13 +132,6 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
             dims=('_num_channel', '_coefs'))
         return data
 
-    def _get_500m_data(self, file_type):
-        chs = [2]
-        cwls = [0.65]
-        data = self._create_channel_data(chs, cwls, file_type)
-
-        return data
-
     def _create_channel_data(self, chs, cwls, file_type):
         dim_0 = 2
         dim_1 = 5
@@ -141,8 +141,19 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
                                                                            [dim_0, dim_1], file_type)
             data['NOMChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'NOM',
                                                                            [dim_0, dim_1], file_type)
+            data['Data/NOMChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'NOM',
+                                                                                [dim_0, dim_1], file_type)
             data['CALIBRATION_COEF(SCALE+OFFSET)'] = self.make_test_data(cwls[index], chs[index], 'COEF',
                                                                          [dim_0, dim_1], file_type)
+            data['Calibration/CALIBRATION_COEF(SCALE+OFFSET)'] = self.make_test_data(cwls[index], chs[index], 'COEF',
+                                                                                     [dim_0, dim_1], file_type)
+        return data
+
+    def _get_500m_data(self, file_type):
+        chs = [2]
+        cwls = [0.65]
+        data = self._create_channel_data(chs, cwls, file_type)
+
         return data
 
     def _get_1km_data(self, file_type):
@@ -170,7 +181,9 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
         dim_0 = 2
         dim_1 = 5
         data = {'NOMSunAzimuth': self.make_test_data('NUL', 'NUL', 'GEO',
-                                                     [dim_0, dim_1], file_type)}
+                                                     [dim_0, dim_1], file_type),
+                'Navigation/NOMSunAzimuth': self.make_test_data('NUL', 'NUL', 'GEO',
+                                                                [dim_0, dim_1], file_type)}
         return data
 
     def get_test_content(self, filename, filename_info, filetype_info):
@@ -212,11 +225,11 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
         return test_content
 
 
-def _create_filenames_from_resolutions(*resolutions):
+def _create_filenames_from_resolutions(satname, *resolutions):
     """Create filenames from the given resolutions."""
     if 'GEO' in resolutions:
-        return ["FY4A-_AGRI--_N_REGC_1047E_L1-_GEO-_MULT_NOM_20190603003000_20190603003416_4000M_V0001.HDF"]
-    pattern = ("FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_"
+        return [f"{satname}-_AGRI--_N_REGC_1047E_L1-_GEO-_MULT_NOM_20190603003000_20190603003416_4000M_V0001.HDF"]
+    pattern = (f"{satname}-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_"
                "{resolution:04d}M_V0001.HDF")
     return [pattern.format(resolution=resolution) for resolution in resolutions]
 
@@ -224,17 +237,20 @@ def _create_filenames_from_resolutions(*resolutions):
 class Test_HDF_AGRI_L1_cal:
     """Test VIRR L1B Reader."""
 
-    yaml_file = "agri_l1.yaml"
+    yaml_file = "agri_fy4a_l1.yaml"
 
     def setup_method(self):
         """Wrap HDF5 file handler with our own fake handler."""
         from satpy._config import config_search_paths
         from satpy.readers.agri_l1 import HDF_AGRI_L1
+        from satpy.readers.fy4_base import FY4Base
         self.reader_configs = config_search_paths(os.path.join('readers', self.yaml_file))
         # http://stackoverflow.com/questions/12219967/how-to-mock-a-base-class-with-python-mock-library
-        self.p = mock.patch.object(HDF_AGRI_L1, '__bases__', (FakeHDF5FileHandler2,))
-        self.fake_handler = self.p.start()
+        self.fy4 = mock.patch.object(FY4Base, '__bases__', (FakeHDF5FileHandler2,))
+        self.p = mock.patch.object(HDF_AGRI_L1.__class__, (self.fy4,))
+        self.fake_handler = self.fy4.start()
         self.p.is_local = True
+        self.satname = 'FY4A'
 
         self.expected = {
                     1: np.array([[2.01, 2.02, 2.03, 2.04, 2.05], [2.06, 2.07, 2.08, 2.09, 2.1]]),
@@ -273,7 +289,7 @@ class Test_HDF_AGRI_L1_cal:
         for resolution_to_test in RESOLUTION_LIST:
             self._check_keys_for_dsq(available_datasets, resolution_to_test)
 
-    def test_fy4a_all_bands_have_right_units(self):
+    def test_agri_all_bands_have_right_units(self):
         """Test all bands have the right units."""
         reader = self._create_reader_for_resolutions(*RESOLUTION_LIST)
 
@@ -285,7 +301,7 @@ class Test_HDF_AGRI_L1_cal:
             assert res[band_name].shape == (2, 5)
             self._check_units(band_name, res)
 
-    def test_fy4a_orbital_parameters_are_correct(self):
+    def test_agri_orbital_parameters_are_correct(self):
         """Test orbital parameters are set correctly."""
         reader = self._create_reader_for_resolutions(*RESOLUTION_LIST)
 
@@ -314,7 +330,7 @@ class Test_HDF_AGRI_L1_cal:
             else:
                 assert len(res) == 3
 
-    def test_fy4a_counts_calibration(self):
+    def test_agri_counts_calibration(self):
         """Test loading data at counts calibration."""
         from satpy.tests.utils import make_dsq
         reader = self._create_reader_for_resolutions(*RESOLUTION_LIST)
@@ -332,9 +348,11 @@ class Test_HDF_AGRI_L1_cal:
             assert res[band_name].dtype == np.uint16
             assert res[band_name].attrs['units'] == "1"
 
-    def test_fy4a_geo(self):
+    @pytest.mark.parametrize("satname", ['FY4A', 'FY4B'])
+    def test_agri_geo(self, satname):
         """Test loading data for angles."""
         from satpy.tests.utils import make_dsq
+        self.satname = satname
         reader = self._create_reader_for_resolutions('GEO')
         band_name = 'solar_azimuth_angle'
         ds_ids = [make_dsq(name=band_name)]
@@ -349,7 +367,7 @@ class Test_HDF_AGRI_L1_cal:
 
     def _create_reader_for_resolutions(self, *resolutions):
         from satpy.readers import load_reader
-        filenames = _create_filenames_from_resolutions(*resolutions)
+        filenames = _create_filenames_from_resolutions(self.satname, *resolutions)
         reader = load_reader(self.reader_configs)
         files = reader.select_files_from_pathnames(filenames)
         assert len(filenames) == len(files)
@@ -359,8 +377,10 @@ class Test_HDF_AGRI_L1_cal:
         return reader
 
     @pytest.mark.parametrize("resolution_to_test", RESOLUTION_LIST)
-    def test_fy4a_for_one_resolution(self, resolution_to_test):
+    @pytest.mark.parametrize("satname", ['FY4A', 'FY4B'])
+    def test_agri_for_one_resolution(self, resolution_to_test, satname):
         """Test loading data when only one resolution is available."""
+        self.satname = satname
         reader = self._create_reader_for_resolutions(resolution_to_test)
 
         available_datasets = reader.available_dataset_ids
@@ -370,7 +390,8 @@ class Test_HDF_AGRI_L1_cal:
         assert len(res) == len(band_names)
         self._check_calibration_and_units(band_names, res)
         for band_name in band_names:
-            assert res[band_name].attrs['area'].area_extent == AREA_EXTENTS_BY_RESOLUTION[resolution_to_test]
+            np.testing.assert_allclose(res[band_name].attrs['area'].area_extent,
+                                       AREA_EXTENTS_BY_RESOLUTION[satname][resolution_to_test])
 
     def _check_calibration_and_units(self, band_names, result):
         for index, band_name in enumerate(band_names):
